Welcome to slang’s documentation! — slang 0.1.0 documentation

# Welcome to slang’s documentation!

Contents:

- slang
- slang.chunkers
- slang.core
- slang.featurizers
- slang.scrap.learning_pipeline_01
- slang.scrap.scrap_01
- slang.scrap.the_apis_i_wish_for
- slang.snip_stats
- slang.snippers
- slang.spectrop
- slang.stypes
- slang.tools
- slang.util
- slang.util_data

# Indices and tables

- Index

- Module Index

- Search Page

Release: 0.1.0

Last change: Nov 25, 2021